@@ -6,6 +6,21 @@
 
 //! `sysinfo` is a crate used to get a system's information.
 //!
+//! ## Supported Oses
+//!
+//! It currently supports the following OSes (alphabetically sorted):
+//!  * Android
+//!  * iOS
+//!  * Linux
+//!  * macOS
+//!  * Windows
+//!
+//! You can still use `sysinfo` on non-supported OSes, it'll simply do nothing and always return
+//! empty values. You can check in your program directly if an OS is supported by checking the
+//! [`SystemExt::IS_SUPPORTED`] constant.
+//!
+//! ## Usage
+//!
 //! /!\ Before any attempt to read the different structs' information, you need to update them to
 //! get up-to-date information because for most of them, it works on diff between the current value
 //! and the old one.
@@ -13,7 +28,7 @@
 //! Which is why, it's much better to keep the same instance of [`System`] around instead of
 //! recreating it multiple times.
 //!
-//! # Examples
+//! ## Examples
 //!
 //! ```
 //! use sysinfo::{ProcessExt, SystemExt};
@@ -24,31 +39,31 @@
 //! system.refresh_all();
 //!
 //! // Now let's print every process' id and name:
-//! for (pid, proc_) in system.get_processes() {
+//! for (pid, proc_) in system.processes() {
 //!     println!("{}:{} => status: {:?}", pid, proc_.name(), proc_.status());
 //! }
 //!
 //! // Then let's print the temperature of the different components:
-//! for component in system.get_components() {
+//! for component in system.components() {
 //!     println!("{:?}", component);
 //! }
 //!
 //! // And then all disks' information:
-//! for disk in system.get_disks() {
+//! for disk in system.disks() {
 //!     println!("{:?}", disk);
 //! }
 //!
 //! // And finally the RAM and SWAP information:
-//! println!("total memory: {} KB", system.get_total_memory());
-//! println!("used memory : {} KB", system.get_used_memory());
-//! println!("total swap  : {} KB", system.get_total_swap());
-//! println!("used swap   : {} KB", system.get_used_swap());
+//! println!("total memory: {} KB", system.total_memory());
+//! println!("used memory : {} KB", system.used_memory());
+//! println!("total swap  : {} KB", system.total_swap());
+//! println!("used swap   : {} KB", system.used_swap());
 //!
 //! // Display system information:
-//! println!("System name:             {:?}", system.get_name());
-//! println!("System kernel version:   {:?}", system.get_kernel_version());
-//! println!("System OS version:       {:?}", system.get_os_version());
-//! println!("System host name:        {:?}", system.get_host_name());
+//! println!("System name:             {:?}", system.name());
+//! println!("System kernel version:   {:?}", system.kernel_version());
+//! println!("System OS version:       {:?}", system.os_version());
+//! println!("System host name:        {:?}", system.host_name());
 //! ```
 
 #![crate_name = "sysinfo"]
@@ -185,15 +200,12 @@ mod test {
 
     #[test]
     fn check_memory_usage() {
-        let mut s = System::new();
-
-        s.refresh_all();
         // We don't want to test on unsupported systems.
-        if MIN_USERS > 0 {
+        if System::IS_SUPPORTED {
+            let mut s = System::new();
+            s.refresh_all();
             assert_eq!(
-                s.get_processes()
-                    .iter()
-                    .all(|(_, proc_)| proc_.memory() == 0),
+                s.processes().iter().all(|(_, proc_)| proc_.memory() == 0),
                 false
             );
         }
@@ -207,7 +219,7 @@ mod test {
         s.refresh_all();
         // All CPU usage will start at zero until the second refresh
         assert_eq!(
-            s.get_processes()
+            s.processes()
                 .iter()
                 .all(|(_, proc_)| proc_.cpu_usage() == 0.0),
             true
@@ -217,10 +229,10 @@ mod test {
         std::thread::sleep(std::time::Duration::from_millis(100));
         s.refresh_all();
         assert_eq!(
-            s.get_processes()
+            s.processes()
                 .iter()
                 .all(|(_, proc_)| proc_.cpu_usage() >= 0.0
-                    && proc_.cpu_usage() <= (s.get_processors().len() as f32) * 100.0),
+                    && proc_.cpu_usage() <= (s.processors().len() as f32) * 100.0),
             true
         );
     }
@@ -228,61 +240,64 @@ mod test {
     #[test]
     fn check_users() {
         let mut s = System::new();
-        assert!(s.get_users().is_empty());
+        assert!(s.users().is_empty());
         s.refresh_users_list();
-        assert!(s.get_users().len() >= MIN_USERS);
+        assert!(s.users().len() >= MIN_USERS);
 
         let mut s = System::new();
-        assert!(s.get_users().is_empty());
+        assert!(s.users().is_empty());
         s.refresh_all();
-        assert!(s.get_users().is_empty());
+        assert!(s.users().is_empty());
 
         let s = System::new_all();
-        assert!(s.get_users().len() >= MIN_USERS);
+        assert!(s.users().len() >= MIN_USERS);
     }
 
     #[test]
     fn check_uid_gid() {
         let mut s = System::new();
-        assert!(s.get_users().is_empty());
+        assert!(s.users().is_empty());
         s.refresh_users_list();
-        let users = s.get_users();
+        let users = s.users();
         assert!(users.len() >= MIN_USERS);
 
-        for user in users {
-            match user.get_name() {
-                "root" => {
-                    assert_eq!(*user.get_uid(), 0);
-                    assert_eq!(*user.get_gid(), 0);
-                }
-                _ => {
-                    assert!(*user.get_uid() > 0);
-                    #[cfg(not(target_os = "windows"))]
-                    assert!(*user.get_gid() > 0);
+        if System::IS_SUPPORTED {
+            #[cfg(not(target_os = "windows"))]
+            {
+                let user = users
+                    .iter()
+                    .find(|u| u.name() == "root")
+                    .expect("no root user");
+                assert_eq!(*user.uid(), 0);
+                assert_eq!(*user.gid(), 0);
+                if let Some(user) = users.iter().find(|u| *u.gid() > 0) {
+                    assert!(*user.uid() > 0);
+                    assert!(*user.gid() > 0);
                 }
             }
+            #[cfg(not(target_os = "windows"))]
+            {
+                assert!(users.iter().filter(|u| *u.uid() > 0).count() > 0);
+            }
         }
     }
 
     #[test]
     fn check_system_info() {
         // We don't want to test on unsupported systems.
-        if MIN_USERS > 0 {
+        if System::IS_SUPPORTED {
             let s = System::new();
-            assert!(!s.get_name().expect("Failed to get system name").is_empty());
+            assert!(!s.name().expect("Failed to get system name").is_empty());
 
             assert!(!s
-                .get_kernel_version()
+                .kernel_version()
                 .expect("Failed to get kernel version")
                 .is_empty());
 
-            assert!(!s
-                .get_os_version()
-                .expect("Failed to get os version")
-                .is_empty());
+            assert!(!s.os_version().expect("Failed to get os version").is_empty());
 
             assert!(!s
-                .get_long_os_version()
+                .long_os_version()
                 .expect("Failed to get long OS version")
                 .is_empty());
         }
@@ -291,19 +306,16 @@ mod test {
     #[test]
     fn check_host_name() {
         // We don't want to test on unsupported systems.
-        if MIN_USERS > 0 {
+        if System::IS_SUPPORTED {
             let s = System::new();
-            assert!(!s
-                .get_host_name()
-                .expect("Failed to get host name")
-                .is_empty());
+            assert!(!s.host_name().expect("Failed to get host name").is_empty());
         }
     }
 
     #[test]
     fn check_refresh_process_return_value() {
         // We don't want to test on unsupported systems.
-        if MIN_USERS > 0 {
+        if System::IS_SUPPORTED {
             let pid = get_current_pid().expect("Failed to get current PID");
             let mut s = System::new();
 
@@ -313,6 +325,33 @@ mod test {
             assert!(s.refresh_process(pid));
         }
     }
+
+    #[test]
+    fn ensure_is_supported_is_set_correctly() {
+        if MIN_USERS > 0 {
+            assert!(System::IS_SUPPORTED);
+        } else {
+            assert!(!System::IS_SUPPORTED);
+        }
+    }
+
+    #[test]
+    fn check_processors_number() {
+        let s = System::new();
+
+        if System::IS_SUPPORTED {
+            assert!(!s.processors().is_empty());
+            // In case we are running inside a VM, it's possible to not have a physical core, only
+            // logical ones, which is why we don't test `physical_cores_count > 0`.
+            let physical_cores_count = s
+                .physical_core_count()
+                .expect("failed to get number of physical cores");
+            assert!(physical_cores_count <= s.processors().len());
+        } else {
+            assert!(s.processors().is_empty());
+            assert_eq!(s.physical_core_count(), None);
+        }
+    }
 }
 
 // Used to check that System is Send and Sync.
