@@ -8,20 +8,18 @@ use crate::sys::component::{self, Component};
 use crate::sys::disk;
 use crate::sys::process::*;
 use crate::sys::processor::*;
+use crate::sys::utils::get_all_data;
 use crate::{Disk, LoadAvg, Networks, Pid, ProcessExt, RefreshKind, SystemExt, User};
 
-use libc::{self, c_char, gid_t, sysconf, uid_t, _SC_CLK_TCK, _SC_HOST_NAME_MAX, _SC_PAGESIZE};
-use std::cell::UnsafeCell;
+use libc::{self, c_char, sysconf, _SC_HOST_NAME_MAX, _SC_PAGESIZE};
 use std::collections::HashMap;
-use std::fs::{self, File};
-use std::io::{self, BufRead, BufReader, Read};
-use std::path::{Path, PathBuf};
+use std::fs::File;
+use std::io::{BufRead, BufReader, Read};
+use std::path::Path;
 use std::str::FromStr;
 use std::sync::{Arc, Mutex};
 use std::time::SystemTime;
 
-use crate::utils::{into_iter, realpath};
-
 // This whole thing is to prevent having too many files open at once. It could be problematic
 // for processes using a lot of files and using sysinfo at the same time.
 #[allow(clippy::mutex_atomic)]
@@ -121,7 +119,6 @@ pub struct System {
     components: Vec<Component>,
     disks: Vec<Disk>,
     networks: Networks,
-    uptime: u64,
     users: Vec<User>,
     boot_time: u64,
 }
@@ -227,6 +224,14 @@ impl System {
                     );
                     self.processors[i].frequency = get_cpu_frequency(i);
                 }
+
+                self.global_processor.frequency = self
+                    .processors
+                    .iter()
+                    .map(|p| p.frequency)
+                    .max()
+                    .unwrap_or(0);
+
                 i += 1;
                 count += 1;
                 if let Some(limit) = limit {
@@ -244,6 +249,8 @@ impl System {
 }
 
 impl SystemExt for System {
+    const IS_SUPPORTED: bool = true;
+
     fn new_with_specifics(refreshes: RefreshKind) -> System {
         let mut s = System {
             process_list: Process::new(0, None, 0),
@@ -276,7 +283,6 @@ impl SystemExt for System {
             components: Vec::new(),
             disks: Vec::with_capacity(2),
             networks: Networks::new(),
-            uptime: get_uptime(),
             users: Vec::new(),
             boot_time: boot_time(),
         };
@@ -292,7 +298,6 @@ impl SystemExt for System {
     }
 
     fn refresh_memory(&mut self) {
-        self.uptime = get_uptime();
         if let Ok(data) = get_all_data("/proc/meminfo", 16_385) {
             for line in data.split('\n') {
                 let field = match line.split(':').next() {
@@ -317,18 +322,17 @@ impl SystemExt for System {
     }
 
     fn refresh_cpu(&mut self) {
-        self.uptime = get_uptime();
         self.refresh_processors(None);
     }
 
     fn refresh_processes(&mut self) {
-        self.uptime = get_uptime();
+        let uptime = self.uptime();
         if refresh_procs(
             &mut self.process_list,
             Path::new("/proc"),
             self.page_size_kb,
             0,
-            self.uptime,
+            uptime,
             get_secs_since_epoch(),
         ) {
             self.clear_procs();
@@ -336,13 +340,13 @@ impl SystemExt for System {
     }
 
     fn refresh_process(&mut self, pid: Pid) -> bool {
-        self.uptime = get_uptime();
+        let uptime = self.uptime();
         let found = match _get_process_data(
             &Path::new("/proc/").join(pid.to_string()),
             &mut self.process_list,
             self.page_size_kb,
             0,
-            self.uptime,
+            uptime,
             get_secs_since_epoch(),
         ) {
             Ok((Some(p), pid)) => {
@@ -376,47 +380,47 @@ impl SystemExt for System {
     //
     // Need to be moved into a "common" file to avoid duplication.
 
-    fn get_processes(&self) -> &HashMap<Pid, Process> {
+    fn processes(&self) -> &HashMap<Pid, Process> {
         &self.process_list.tasks
     }
 
-    fn get_process(&self, pid: Pid) -> Option<&Process> {
+    fn process(&self, pid: Pid) -> Option<&Process> {
         self.process_list.tasks.get(&pid)
     }
 
-    fn get_networks(&self) -> &Networks {
+    fn networks(&self) -> &Networks {
         &self.networks
     }
 
-    fn get_networks_mut(&mut self) -> &mut Networks {
+    fn networks_mut(&mut self) -> &mut Networks {
         &mut self.networks
     }
 
-    fn get_global_processor_info(&self) -> &Processor {
+    fn global_processor_info(&self) -> &Processor {
         &self.global_processor
     }
 
-    fn get_processors(&self) -> &[Processor] {
+    fn processors(&self) -> &[Processor] {
         &self.processors
     }
 
-    fn get_physical_core_count(&self) -> Option<usize> {
+    fn physical_core_count(&self) -> Option<usize> {
         get_physical_core_count()
     }
 
-    fn get_total_memory(&self) -> u64 {
+    fn total_memory(&self) -> u64 {
         self.mem_total
     }
 
-    fn get_free_memory(&self) -> u64 {
+    fn free_memory(&self) -> u64 {
         self.mem_free
     }
 
-    fn get_available_memory(&self) -> u64 {
+    fn available_memory(&self) -> u64 {
         self.mem_available
     }
 
-    fn get_used_memory(&self) -> u64 {
+    fn used_memory(&self) -> u64 {
         self.mem_total
             - self.mem_free
             - self.mem_buffers
@@ -424,44 +428,49 @@ impl SystemExt for System {
             - self.mem_slab_reclaimable
     }
 
-    fn get_total_swap(&self) -> u64 {
+    fn total_swap(&self) -> u64 {
         self.swap_total
     }
 
-    fn get_free_swap(&self) -> u64 {
+    fn free_swap(&self) -> u64 {
         self.swap_free
     }
 
     // need to be checked
-    fn get_used_swap(&self) -> u64 {
+    fn used_swap(&self) -> u64 {
         self.swap_total - self.swap_free
     }
 
-    fn get_components(&self) -> &[Component] {
+    fn components(&self) -> &[Component] {
         &self.components
     }
 
-    fn get_components_mut(&mut self) -> &mut [Component] {
+    fn components_mut(&mut self) -> &mut [Component] {
         &mut self.components
     }
 
-    fn get_disks(&self) -> &[Disk] {
+    fn disks(&self) -> &[Disk] {
         &self.disks
     }
 
-    fn get_disks_mut(&mut self) -> &mut [Disk] {
+    fn disks_mut(&mut self) -> &mut [Disk] {
         &mut self.disks
     }
 
-    fn get_uptime(&self) -> u64 {
-        self.uptime
+    fn uptime(&self) -> u64 {
+        let content = get_all_data("/proc/uptime", 50).unwrap_or_default();
+        content
+            .split('.')
+            .next()
+            .and_then(|t| t.parse().ok())
+            .unwrap_or_default()
     }
 
-    fn get_boot_time(&self) -> u64 {
+    fn boot_time(&self) -> u64 {
         self.boot_time
     }
 
-    fn get_load_average(&self) -> LoadAvg {
+    fn load_average(&self) -> LoadAvg {
         let mut s = String::new();
         if File::open("/proc/loadavg")
             .and_then(|mut f| f.read_to_string(&mut s))
@@ -482,12 +491,12 @@ impl SystemExt for System {
         }
     }
 
-    fn get_users(&self) -> &[User] {
+    fn users(&self) -> &[User] {
         &self.users
     }
 
     #[cfg(not(target_os = "android"))]
-    fn get_name(&self) -> Option<String> {
+    fn name(&self) -> Option<String> {
         get_system_info_linux(
             InfoType::Name,
             Path::new("/etc/os-release"),
@@ -496,11 +505,11 @@ impl SystemExt for System {
     }
 
     #[cfg(target_os = "android")]
-    fn get_name(&self) -> Option<String> {
+    fn name(&self) -> Option<String> {
         get_system_info_android(InfoType::Name)
     }
 
-    fn get_long_os_version(&self) -> Option<String> {
+    fn long_os_version(&self) -> Option<String> {
         #[cfg(target_os = "android")]
         let system_name = "Android";
 
@@ -510,12 +519,12 @@ impl SystemExt for System {
         Some(format!(
             "{} {} {}",
             system_name,
-            self.get_os_version().unwrap_or_default(),
-            self.get_name().unwrap_or_default()
+            self.os_version().unwrap_or_default(),
+            self.name().unwrap_or_default()
         ))
     }
 
-    fn get_host_name(&self) -> Option<String> {
+    fn host_name(&self) -> Option<String> {
         let hostname_max = unsafe { sysconf(_SC_HOST_NAME_MAX) };
         let mut buffer = vec![0_u8; hostname_max as usize];
         if unsafe { libc::gethostname(buffer.as_mut_ptr() as *mut c_char, buffer.len()) } == 0 {
@@ -530,7 +539,7 @@ impl SystemExt for System {
         }
     }
 
-    fn get_kernel_version(&self) -> Option<String> {
+    fn kernel_version(&self) -> Option<String> {
         let mut raw = std::mem::MaybeUninit::<libc::utsname>::zeroed();
 
         if unsafe { libc::uname(raw.as_mut_ptr()) } == 0 {
@@ -550,7 +559,7 @@ impl SystemExt for System {
     }
 
     #[cfg(not(target_os = "android"))]
-    fn get_os_version(&self) -> Option<String> {
+    fn os_version(&self) -> Option<String> {
         get_system_info_linux(
             InfoType::OsVersion,
             Path::new("/etc/os-release"),
@@ -559,7 +568,7 @@ impl SystemExt for System {
     }
 
     #[cfg(target_os = "android")]
-    fn get_os_version(&self) -> Option<String> {
+    fn os_version(&self) -> Option<String> {
         get_system_info_android(InfoType::OsVersion)
     }
 }
@@ -580,204 +589,6 @@ fn to_u64(v: &[u8]) -> u64 {
     x
 }
 
-struct Wrap<'a, T>(UnsafeCell<&'a mut T>);
-
-impl<'a, T> Wrap<'a, T> {
-    fn get(&self) -> &'a mut T {
-        unsafe { *(self.0.get()) }
-    }
-}
-
-unsafe impl<'a, T> Send for Wrap<'a, T> {}
-unsafe impl<'a, T> Sync for Wrap<'a, T> {}
-
-fn refresh_procs(
-    proc_list: &mut Process,
-    path: &Path,
-    page_size_kb: u64,
-    pid: Pid,
-    uptime: u64,
-    now: u64,
-) -> bool {
-    if let Ok(d) = fs::read_dir(path) {
-        let folders = d
-            .filter_map(|entry| {
-                if let Ok(entry) = entry {
-                    let entry = entry.path();
-
-                    if entry.is_dir() {
-                        Some(entry)
-                    } else {
-                        None
-                    }
-                } else {
-                    None
-                }
-            })
-            .collect::<Vec<_>>();
-        if pid == 0 {
-            let proc_list = Wrap(UnsafeCell::new(proc_list));
-
-            #[cfg(feature = "multithread")]
-            use rayon::iter::ParallelIterator;
-
-            into_iter(folders)
-                .filter_map(|e| {
-                    if let Ok((p, _)) = _get_process_data(
-                        e.as_path(),
-                        proc_list.get(),
-                        page_size_kb,
-                        pid,
-                        uptime,
-                        now,
-                    ) {
-                        p
-                    } else {
-                        None
-                    }
-                })
-                .collect::<Vec<_>>()
-        } else {
-            let mut updated_pids = Vec::with_capacity(folders.len());
-            let new_tasks = folders
-                .iter()
-                .filter_map(|e| {
-                    if let Ok((p, pid)) =
-                        _get_process_data(e.as_path(), proc_list, page_size_kb, pid, uptime, now)
-                    {
-                        updated_pids.push(pid);
-                        p
-                    } else {
-                        None
-                    }
-                })
-                .collect::<Vec<_>>();
-            // Sub-tasks are not cleaned up outside so we do it here directly.
-            proc_list
-                .tasks
-                .retain(|&pid, _| updated_pids.iter().any(|&x| x == pid));
-            new_tasks
-        }
-        .into_iter()
-        .for_each(|e| {
-            proc_list.tasks.insert(e.pid(), e);
-        });
-        true
-    } else {
-        false
-    }
-}
-
-#[allow(clippy::too_many_arguments)]
-fn update_time_and_memory(
-    path: &Path,
-    entry: &mut Process,
-    parts: &[&str],
-    page_size_kb: u64,
-    parent_memory: u64,
-    parent_virtual_memory: u64,
-    pid: Pid,
-    uptime: u64,
-    now: u64,
-) {
-    {
-        // rss
-        entry.memory = u64::from_str(parts[23]).unwrap_or(0) * page_size_kb;
-        if entry.memory >= parent_memory {
-            entry.memory -= parent_memory;
-        }
-        // vsz
-        entry.virtual_memory = u64::from_str(parts[22]).unwrap_or(0);
-        if entry.virtual_memory >= parent_virtual_memory {
-            entry.virtual_memory -= parent_virtual_memory;
-        }
-        set_time(
-            entry,
-            u64::from_str(parts[13]).unwrap_or(0),
-            u64::from_str(parts[14]).unwrap_or(0),
-        );
-    }
-    refresh_procs(entry, &path.join("task"), page_size_kb, pid, uptime, now);
-}
-
-macro_rules! unwrap_or_return {
-    ($data:expr) => {{
-        match $data {
-            Some(x) => x,
-            None => return Err(()),
-        }
-    }};
-}
-
-fn _get_uid_and_gid(status_data: String) -> Option<(uid_t, gid_t)> {
-    // We're only interested in the lines starting with Uid: and Gid:
-    // here. From these lines, we're looking at the second entry to get
-    // the effective u/gid.
-
-    let f = |h: &str, n: &str| -> Option<uid_t> {
-        if h.starts_with(n) {
-            h.split_whitespace().nth(2).unwrap_or("0").parse().ok()
-        } else {
-            None
-        }
-    };
-    let mut uid = None;
-    let mut gid = None;
-    for line in status_data.lines() {
-        if let Some(u) = f(line, "Uid:") {
-            assert!(uid.is_none());
-            uid = Some(u);
-        } else if let Some(g) = f(line, "Gid:") {
-            assert!(gid.is_none());
-            gid = Some(g);
-        } else {
-            continue;
-        }
-        if uid.is_some() && gid.is_some() {
-            break;
-        }
-    }
-    match (uid, gid) {
-        (Some(u), Some(g)) => Some((u, g)),
-        _ => None,
-    }
-}
-
-fn parse_stat_file(data: &str) -> Result<Vec<&str>, ()> {
-    // The stat file is "interesting" to parse, because spaces cannot
-    // be used as delimiters. The second field stores the command name
-    // surrounded by parentheses. Unfortunately, whitespace and
-    // parentheses are legal parts of the command, so parsing has to
-    // proceed like this: The first field is delimited by the first
-    // whitespace, the second field is everything until the last ')'
-    // in the entire string. All other fields are delimited by
-    // whitespace.
-
-    let mut parts = Vec::with_capacity(52);
-    let mut data_it = data.splitn(2, ' ');
-    parts.push(unwrap_or_return!(data_it.next()));
-    let mut data_it = unwrap_or_return!(data_it.next()).rsplitn(2, ')');
-    let data = unwrap_or_return!(data_it.next());
-    parts.push(unwrap_or_return!(data_it.next()));
-    parts.extend(data.split_whitespace());
-    // Remove command name '('
-    if let Some(name) = parts[1].strip_prefix('(') {
-        parts[1] = name;
-    }
-    Ok(parts)
-}
-
-fn check_nb_open_files(f: File) -> Option<File> {
-    if let Ok(ref mut x) = unsafe { REMAINING_FILES.lock() } {
-        if **x > 0 {
-            **x -= 1;
-            return Some(f);
-        }
-    }
-    // Something bad happened...
-    None
-}
-
 #[derive(PartialEq)]
 enum InfoType {
     /// The end-user friendly name of:
@@ -857,193 +668,6 @@ fn get_system_info_android(info: InfoType) -> Option<String> {
     }
 }
 
-fn _get_process_data(
-    path: &Path,
-    proc_list: &mut Process,
-    page_size_kb: u64,
-    pid: Pid,
-    uptime: u64,
-    now: u64,
-) -> Result<(Option<Process>, Pid), ()> {
-    let nb = match path.file_name().and_then(|x| x.to_str()).map(Pid::from_str) {
-        Some(Ok(nb)) if nb != pid => nb,
-        _ => return Err(()),
-    };
-
-    let get_status = |p: &mut Process, part: &str| {
-        p.status = part
-            .chars()
-            .next()
-            .map(ProcessStatus::from)
-            .unwrap_or_else(|| ProcessStatus::Unknown(0));
-    };
-    let parent_memory = proc_list.memory;
-    let parent_virtual_memory = proc_list.virtual_memory;
-    if let Some(ref mut entry) = proc_list.tasks.get_mut(&nb) {
-        let data = if let Some(ref mut f) = entry.stat_file {
-            get_all_data_from_file(f, 1024).map_err(|_| ())?
-        } else {
-            let mut tmp = PathBuf::from(path);
-            tmp.push("stat");
-            let mut file = File::open(tmp).map_err(|_| ())?;
-            let data = get_all_data_from_file(&mut file, 1024).map_err(|_| ())?;
-            entry.stat_file = check_nb_open_files(file);
-            data
-        };
-        let parts = parse_stat_file(&data)?;
-        get_status(entry, parts[2]);
-        update_time_and_memory(
-            path,
-            entry,
-            &parts,
-            page_size_kb,
-            parent_memory,
-            parent_virtual_memory,
-            nb,
-            uptime,
-            now,
-        );
-        update_process_disk_activity(entry, path);
-        return Ok((None, nb));
-    }
-
-    let mut tmp = PathBuf::from(path);
-
-    tmp.push("stat");
-    let mut file = std::fs::File::open(&tmp).map_err(|_| ())?;
-    let data = get_all_data_from_file(&mut file, 1024).map_err(|_| ())?;
-    let stat_file = check_nb_open_files(file);
-    let parts = parse_stat_file(&data)?;
-    let name = parts[1];
-
-    let parent_pid = if proc_list.pid != 0 {
-        Some(proc_list.pid)
-    } else {
-        match Pid::from_str(parts[3]) {
-            Ok(p) if p != 0 => Some(p),
-            _ => None,
-        }
-    };
-
-    let clock_cycle = unsafe { sysconf(_SC_CLK_TCK) } as u64;
-    let since_boot = u64::from_str(parts[21]).unwrap_or(0) / clock_cycle;
-    let start_time = now.saturating_sub(uptime.saturating_sub(since_boot));
-    let mut p = Process::new(nb, parent_pid, start_time);
-
-    p.stat_file = stat_file;
-    get_status(&mut p, parts[2]);
-
-    tmp.pop();
-    tmp.push("status");
-    if let Ok(data) = get_all_data(&tmp, 16_385) {
-        if let Some((uid, gid)) = _get_uid_and_gid(data) {
-            p.uid = uid;
-            p.gid = gid;
-        }
-    }
-
-    if proc_list.pid != 0 {
-        // If we're getting information for a child, no need to get those info since we
-        // already have them...
-        p.cmd = proc_list.cmd.clone();
-        p.name = proc_list.name.clone();
-        p.environ = proc_list.environ.clone();
-        p.exe = proc_list.exe.clone();
-        p.cwd = proc_list.cwd.clone();
-        p.root = proc_list.root.clone();
-    } else {
-        p.name = name.into();
-        tmp.pop();
-        tmp.push("cmdline");
-        p.cmd = copy_from_file(&tmp);
-        tmp.pop();
-        tmp.push("exe");
-        match tmp.read_link() {
-            Ok(exe_path) => {
-                p.exe = exe_path;
-            }
-            Err(_) => {
-                p.exe = PathBuf::new();
-            }
-        }
-        tmp.pop();
-        tmp.push("environ");
-        p.environ = copy_from_file(&tmp);
-        tmp.pop();
-        tmp.push("cwd");
-        p.cwd = realpath(&tmp);
-        tmp.pop();
-        tmp.push("root");
-        p.root = realpath(&tmp);
-    }
-
-    update_time_and_memory(
-        path,
-        &mut p,
-        &parts,
-        page_size_kb,
-        proc_list.memory,
-        proc_list.virtual_memory,
-        nb,
-        uptime,
-        now,
-    );
-    update_process_disk_activity(&mut p, path);
-    Ok((Some(p), nb))
-}
-
-fn copy_from_file(entry: &Path) -> Vec<String> {
-    match File::open(entry) {
-        Ok(mut f) => {
-            let mut data = vec![0; 16_384];
-
-            if let Ok(size) = f.read(&mut data) {
-                data.truncate(size);
-                let mut out = Vec::with_capacity(20);
-                let mut start = 0;
-                for (pos, x) in data.iter().enumerate() {
-                    if *x == 0 {
-                        if pos - start >= 1 {
-                            if let Ok(s) =
-                                std::str::from_utf8(&data[start..pos]).map(|x| x.trim().to_owned())
-                            {
-                                out.push(s);
-                            }
-                        }
-                        start = pos + 1; // to keeping prevent '\0'
-                    }
-                }
-                out
-            } else {
-                Vec::new()
-            }
-        }
-        Err(_) => Vec::new(),
-    }
-}
-
-fn get_all_data_from_file(file: &mut File, size: usize) -> io::Result<String> {
-    use std::io::Seek;
-    let mut buf = String::with_capacity(size);
-    file.seek(::std::io::SeekFrom::Start(0))?;
-    file.read_to_string(&mut buf)?;
-    Ok(buf)
-}
-
-pub fn get_all_data<P: AsRef<Path>>(file_path: P, size: usize) -> io::Result<String> {
-    let mut file = File::open(file_path.as_ref())?;
-    get_all_data_from_file(&mut file, size)
-}
-
-fn get_uptime() -> u64 {
-    let content = get_all_data("/proc/uptime", 50).unwrap_or_default();
-    content
-        .split('.')
-        .next()
-        .and_then(|t| t.parse().ok())
-        .unwrap_or_default()
-}
-
 fn get_secs_since_epoch() -> u64 {
     match SystemTime::now().duration_since(SystemTime::UNIX_EPOCH) {
         Ok(n) => n.as_secs(),
